@@ -38,14 +38,7 @@
 #include "ar-string-utils.h"
 #include "ar-gsettings.h"
 
-#ifdef HAVE_CLUTTER
-#include "ar-clutter-embed.h"
-#include "ar-style.h"
-#include "baize.h"
-#include "board.h"
-#else
 #include "board-noclutter.h"
-#endif
 
 #include "ar-card-theme.h"
 #include "ar-card-themes.h"
@@ -96,13 +89,7 @@ struct _AisleriotWindowPrivate
 {
   AisleriotGame *game;
   ArStyle *board_style;
-#ifdef HAVE_CLUTTER
-  ArClutterEmbed *board;
-  ClutterActor *baize_actor;
-  ClutterActor *board_actor;
-#else
   AisleriotBoard *board;
-#endif
 
   ArCardThemes *theme_manager;
   ArCardTheme *theme;
@@ -186,7 +173,7 @@ game_over_dialog_response_cb (GtkWidget *dialog,
       aisleriot_game_restart_game (priv->game);
       break;
     case RESPONSE_NEW_GAME:
-      aisleriot_game_new_game (priv->game, NULL);
+      aisleriot_game_new_game (priv->game);
       break;
     case GTK_RESPONSE_CLOSE:
       gtk_widget_destroy (GTK_WIDGET (window)); /* this will quit */
@@ -199,7 +186,7 @@ game_over_dialog_response_cb (GtkWidget *dialog,
        * thing to do.
        */
       if (game_won) {
-        aisleriot_game_new_game (priv->game, NULL);
+        aisleriot_game_new_game (priv->game);
       } else {
         aisleriot_game_undo_move (priv->game);
       }
@@ -320,7 +307,7 @@ new_game_cb (GtkAction *action,
 {
   AisleriotWindowPrivate *priv = window->priv;
 
-  aisleriot_game_new_game (priv->game, NULL);
+  aisleriot_game_new_game (priv->game);
 
   gtk_widget_grab_focus (GTK_WIDGET (priv->board));
 }
@@ -332,11 +319,7 @@ undo_cb (GtkAction *action,
   AisleriotWindowPrivate *priv = window->priv;
 
   /* If a move is in progress, cancel it before changing the game! */
-#ifdef HAVE_CLUTTER
-  aisleriot_board_abort_move (AISLERIOT_BOARD (priv->board_actor));
-#else
   aisleriot_board_abort_move (priv->board);
-#endif
 
   aisleriot_game_undo_move (priv->game);
 }
@@ -347,11 +330,7 @@ redo_cb (GtkAction *action,
 {
   AisleriotWindowPrivate *priv = window->priv;
 
-#ifdef HAVE_CLUTTER
-  aisleriot_board_abort_move (AISLERIOT_BOARD (priv->board_actor));
-#else
   aisleriot_board_abort_move (priv->board);
-#endif
 
   aisleriot_game_redo_move (priv->game);
 }
@@ -381,6 +360,7 @@ help_about_cb (GtkAction *action,
     "Alan Horkan <horkana@maths.tcd.ie>",
     "Richard Hoelscher <rah@rahga.com>",
     "Vincent Povirk",
+    "Sapphire Becker",
     NULL
   };
   const char *artists[] = {
@@ -647,7 +627,7 @@ debug_cycle_timeout_cb (AisleriotWindow *window)
     return FALSE;
 
   game_file = data->current_game->data;  
-  aisleriot_window_set_game (data->window, game_file, 0);
+  aisleriot_window_set_game (data->window, game_file, NULL);
 
   return TRUE;
 }
@@ -670,7 +650,7 @@ debug_game_first (GtkAction *action,
   if (!data->current_game)
     return;
 
-  aisleriot_window_set_game (data->window, (const char *) data->current_game->data, 0);
+  aisleriot_window_set_game (data->window, (const char *) data->current_game->data, NULL);
 }
 
 static void
@@ -684,7 +664,7 @@ debug_game_last (GtkAction *action,
   if (!data->current_game)
     return;
 
-  aisleriot_window_set_game (data->window, (const char *) data->current_game->data, 0);
+  aisleriot_window_set_game (data->window, (const char *) data->current_game->data, NULL);
 }
 
 static void
@@ -703,7 +683,7 @@ debug_game_next (GtkAction *action,
   if (!data->current_game)
     return;
 
-  aisleriot_window_set_game (data->window, (const char *) data->current_game->data, 0);
+  aisleriot_window_set_game (data->window, (const char *) data->current_game->data, NULL);
 }
 
 static void
@@ -722,7 +702,7 @@ debug_game_prev (GtkAction *action,
   if (!data->current_game)
     return;
 
-  aisleriot_window_set_game (data->window, (const char *) data->current_game->data, 0);
+  aisleriot_window_set_game (data->window, (const char *) data->current_game->data, NULL);
 }
 
 static void
@@ -736,6 +716,7 @@ debug_choose_seed_response_cb (GtkWidget *dialog,
     const char *text;
     char *endptr;
     guint seed;
+    GRand *rand;
 
     entry = g_object_get_data (G_OBJECT (dialog), "entry");
     text = gtk_entry_get_text (entry);
@@ -743,7 +724,9 @@ debug_choose_seed_response_cb (GtkWidget *dialog,
     errno = 0;
     seed = g_ascii_strtoull (text, &endptr, 10);
     if (errno == 0 && endptr != text) {
-      aisleriot_game_new_game (priv->game, &seed);
+      rand = g_rand_new_with_seed (seed);
+
+      aisleriot_game_new_game_with_rand (priv->game, rand /* adopts */);
 
       gtk_widget_grab_focus (GTK_WIDGET (priv->board));
     }
@@ -756,9 +739,7 @@ static void
 debug_choose_seed_cb (GtkAction *action,
                       AisleriotWindow *window)
 {
-  AisleriotWindowPrivate *priv = window->priv;
   GtkWidget *dialog, *entry;
-  char str[32];
 
   dialog = gtk_message_dialog_new (GTK_WINDOW (window),
                                    GTK_DIALOG_DESTROY_WITH_PARENT |
@@ -770,9 +751,16 @@ debug_choose_seed_cb (GtkAction *action,
                     G_CALLBACK (debug_choose_seed_response_cb), window);
   gtk_dialog_set_default_response (GTK_DIALOG (dialog), GTK_RESPONSE_OK);
 
-  g_snprintf (str, sizeof (str), "%u", aisleriot_game_get_seed (priv->game));
   entry = gtk_entry_new ();
+
+  #if 0
+{
+  char str[32];
+  g_snprintf (str, sizeof (str), "%u", aisleriot_game_get_seed (priv->game));
   gtk_entry_set_text (GTK_ENTRY (entry), str);
+}
+#endif
+
   gtk_box_pack_end (GTK_BOX (gtk_message_dialog_get_message_area (GTK_MESSAGE_DIALOG (dialog))), entry, FALSE, FALSE, 0);
   gtk_widget_show (entry);
   g_object_set_data (G_OBJECT (dialog), "entry", entry);
@@ -957,24 +945,6 @@ sound_toggle_cb (GtkToggleAction *action,
 
 #endif /* ENABLE_SOUND */
 
-#ifdef HAVE_CLUTTER
-
-static void
-animations_toggle_cb (GtkToggleAction *action,
-                      AisleriotWindow *window)
-{
-  AisleriotWindowPrivate *priv = window->priv;
-  gboolean enabled;
-
-  enabled = gtk_toggle_action_get_active (action);
-
-  ar_style_set_enable_animations (priv->board_style, enabled);
-  
-  ar_conf_set_boolean (NULL, aisleriot_conf_get_key (CONF_ANIMATIONS), enabled);
-}
-
-#endif /* HAVE_CLUTTER */
-
 static void
 show_hint_cb (GtkAction *action,
               AisleriotWindow *window)
@@ -1095,7 +1065,7 @@ option_cb (GtkToggleAction *action,
   aisleriot_conf_set_options (aisleriot_game_get_game_file (priv->game), (int) value);
 
   /* Now re-deal, so the option is applied */
-  aisleriot_game_new_game (priv->game, NULL);
+  aisleriot_game_new_game (priv->game);
 }
 
 static void
@@ -1248,7 +1218,7 @@ recent_game_cb (GtkAction *action,
   game_file = g_object_get_data (G_OBJECT (action), "game");
   g_return_if_fail (game_file != NULL);
 
-  aisleriot_window_set_game (window, game_file, 0);
+  aisleriot_window_set_game (window, game_file, NULL);
   
   ar_conf_set_string (NULL, aisleriot_conf_get_key (CONF_VARIATION), game_file);
 }
@@ -1734,7 +1704,7 @@ game_exception_response_cb (GtkWidget *dialog,
   gtk_widget_destroy (dialog);
 
   /* Start a new game */
-  aisleriot_game_new_game (priv->game, NULL);
+  aisleriot_game_new_game (priv->game);
 
   gtk_widget_grab_focus (GTK_WIDGET (priv->board));
 }
@@ -1779,7 +1749,7 @@ game_exception_cb (AisleriotGame *game,
   gtk_widget_show (dialog);
 }
 
-#if defined(HAVE_CLUTTER) || defined(ENABLE_SOUND)
+#if defined(ENABLE_SOUND)
 
 static void
 settings_changed_cb (GtkSettings *settings,
@@ -1796,23 +1766,12 @@ settings_changed_cb (GtkSettings *settings,
   else
     name = NULL;
 
-#ifdef HAVE_CLUTTER
-  if (name == NULL || strcmp (name, "gtk-enable-animations") == 0) {
-    g_object_get (settings, "gtk-enable-animations", &enabled, NULL);
-
-    action = gtk_action_group_get_action (priv->action_group, "Animations");
-    gtk_action_set_visible (action, enabled);
-  }
-#endif /* HAVE_CLUTTER */
-
-#if defined(ENABLE_SOUND)
   if (name == NULL || strcmp (name, "gtk-enable-event-sounds") == 0) {
     g_object_get (settings, "gtk-enable-event-sounds", &enabled, NULL);
 
     action = gtk_action_group_get_action (priv->action_group, "Sound");
     gtk_action_set_visible (action, enabled);
   }
-#endif /* ENABLE_SOUND */
 }
 
 static void
@@ -1840,17 +1799,11 @@ screen_changed_cb (GtkWidget *widget,
 
   settings = gtk_widget_get_settings (widget);
   settings_changed_cb (settings, NULL, window);
-#ifdef HAVE_CLUTTER
-  g_signal_connect (settings, "notify::gtk-enable-animations",
-                    G_CALLBACK (settings_changed_cb), window);
-#endif
-#if defined (ENABLE_SOUND)
   g_signal_connect (settings, "notify::gtk-enable-event-sounds",
                     G_CALLBACK (settings_changed_cb), window);
-#endif
 }
 
-#endif /* HAVE_CLUTTER || ENABLE_SOUND */
+#endif /* ENABLE_SOUND */
 
 /*
  * aisleriot_window_set_freecell_mode:
@@ -1896,35 +1849,6 @@ board_status_message_cb (AisleriotBoard *board,
   }
 }
 
-#ifdef HAVE_CLUTTER
-
-static void
-board_cursor_cb (AisleriotBoard *board,
-                 int cursor_type,
-                 ArClutterEmbed *embed)
-{
-  ar_clutter_embed_set_cursor (embed, (ArCursorType) cursor_type);
-}
-
-static void
-board_error_bell_cb (AisleriotBoard *board,
-                     ArClutterEmbed *embed)
-{
-  gtk_widget_error_bell (GTK_WIDGET (embed));
-}
-
-static void
-embed_size_allocate_cb (ArClutterEmbed *embed,
-                        GtkAllocation *allocation,
-                        AisleriotWindow *window)
-{
-  AisleriotWindowPrivate *priv = window->priv;
-
-  clutter_actor_set_size (priv->board_actor, allocation->width, allocation->height);
-}
-
-#endif /* HAVE_CLUTTER */
-
 /* Class implementation */
 
 G_DEFINE_TYPE (AisleriotWindow, aisleriot_window, GTK_TYPE_WINDOW)
@@ -2104,12 +2028,6 @@ aisleriot_window_init (AisleriotWindow *window)
       G_CALLBACK (sound_toggle_cb),
       FALSE /* not active by default */ },
 #endif /* ENABLE_SOUND */
-#ifdef HAVE_CLUTTER
-   { "Animations", NULL, N_("_Animations"), NULL,
-      N_("Whether or not to animate card moves"),
-      G_CALLBACK (animations_toggle_cb),
-      FALSE /* not active by default */ },
-#endif /* HAVE_CLUTTER */
   };
 
   static const char names[][16] = {
@@ -2156,9 +2074,6 @@ aisleriot_window_init (AisleriotWindow *window)
           "<menuitem action='ClickToMove'/>"
 #ifdef ENABLE_SOUND
           "<menuitem action='Sound'/>"
-#endif
-#ifdef HAVE_CLUTTER
-          "<menuitem action='Animations'/>"
 #endif
         "</menu>"
         "<menu action='OptionsMenu'/>"
@@ -2215,9 +2130,6 @@ aisleriot_window_init (AisleriotWindow *window)
   guint i;
   GtkStatusbar *statusbar;
   GtkWidget *statusbar_hbox, *label, *time_box;
-#ifdef HAVE_CLUTTER
-  ClutterContainer *stage;
-#endif
 
   g_assert (G_N_ELEMENTS (names) == LAST_ACTION);
 
@@ -2231,34 +2143,7 @@ aisleriot_window_init (AisleriotWindow *window)
 
   priv->board_style = ar_style_new ();
 
-#ifdef HAVE_CLUTTER
-  priv->board = ar_clutter_embed_new (priv->board_style);
-
-  priv->baize_actor = aisleriot_baize_new ();
-
-  stage = CLUTTER_CONTAINER (gtk_clutter_embed_get_stage (GTK_CLUTTER_EMBED (priv->board)));
-  clutter_container_add (stage, priv->baize_actor, NULL);
-  /* FIXMEchpe: how to ensure this is ALWAYS the lowest actor? */
-  clutter_actor_lower_bottom (priv->baize_actor);
-
-  priv->board_actor = aisleriot_board_new (priv->board_style, priv->game);
-  clutter_container_add (stage, priv->board_actor, NULL);
-
-  /* FIXMEchpe */
-  clutter_stage_set_key_focus (CLUTTER_STAGE (stage), priv->board_actor);
-
-  g_signal_connect_after (priv->board, "size-allocate",
-                          G_CALLBACK (embed_size_allocate_cb), window);
-
-  g_signal_connect (priv->board_actor, "request-cursor",
-                    G_CALLBACK (board_cursor_cb), priv->board);
-  g_signal_connect (priv->board_actor, "error-bell",
-                    G_CALLBACK (board_error_bell_cb), priv->board);
-
-  /* FIXMEchpe: unref baize & board_actor here? */
-#else
   priv->board = AISLERIOT_BOARD (aisleriot_board_new (priv->board_style, priv->game));
-#endif /* HAVE_CLUTTER */
 
   theme_name = ar_conf_get_string (NULL, aisleriot_conf_get_key (CONF_THEME), NULL);
   theme = ar_card_themes_get_theme_by_name (priv->theme_manager, theme_name);
@@ -2309,13 +2194,8 @@ aisleriot_window_init (AisleriotWindow *window)
 
   priv->game_message_id = gtk_statusbar_get_context_id (priv->statusbar, "board-message");
 
-#ifdef HAVE_CLUTTER
-  g_signal_connect (priv->board_actor, "status-message",
-                    G_CALLBACK (board_status_message_cb), window);
-#else
   g_signal_connect (priv->board, "status-message",
                     G_CALLBACK (board_status_message_cb), window);
-#endif
 
   gtk_window_set_has_resize_grip (GTK_WINDOW (window), TRUE);
 
@@ -2408,19 +2288,12 @@ aisleriot_window_init (AisleriotWindow *window)
 
   set_fullscreen_actions (window, FALSE);
 
-#ifdef HAVE_CLUTTER
-  action = gtk_action_group_get_action (priv->action_group, "Animations");
-  gtk_toggle_action_set_active (GTK_TOGGLE_ACTION (action),
-                                ar_conf_get_boolean (NULL, aisleriot_conf_get_key (CONF_ANIMATIONS), NULL));
-
-#endif /* HAVE_CLUTTER */
-
-#if defined(HAVE_CLUTTER) || defined(ENABLE_SOUND)
+#if defined(ENABLE_SOUND)
   /* Set the action visibility and listen for animation and sound mode changes */
   screen_changed_cb (GTK_WIDGET (window), NULL, window);
   g_signal_connect (window, "screen-changed",
                     G_CALLBACK (screen_changed_cb), window);
-#endif /* HAVE_CLUTTER || ENABLE_SOUND */
+#endif /* ENABLE_SOUND */
 
   /* Now set up the widgets */
   main_vbox = gtk_vbox_new (FALSE, 0);
@@ -2476,12 +2349,12 @@ aisleriot_window_dispose (GObject *object)
 {
   AisleriotWindow *window = AISLERIOT_WINDOW (object);
   AisleriotWindowPrivate *priv = window->priv;
-  
-#ifdef HAVE_CLUTTER
+
+#ifdef ENABLE_SOUND
   g_signal_handlers_disconnect_by_func (gtk_widget_get_settings (GTK_WIDGET (window)),
                                         G_CALLBACK (settings_changed_cb),
                                         window);
-#endif /* HAVE_CLUTTER */
+#endif /* ENABLE_SOUND */
 
   if (priv->hint_dialog) {
     gtk_widget_destroy (priv->hint_dialog);
@@ -2521,10 +2394,6 @@ aisleriot_window_finalize (GObject *object)
   AisleriotWindow *window = AISLERIOT_WINDOW (object);
   AisleriotWindowPrivate *priv = window->priv;
 
-#ifdef HAVE_CLUTTER
-  g_object_unref (priv->board_style);
-#endif /* HAVE_CLUTTER */
-
   if (priv->theme) {
     g_object_unref (priv->theme);
   }
@@ -2604,7 +2473,7 @@ aisleriot_window_new (gboolean freecell_mode)
 typedef struct {
   AisleriotWindow *window;
   char *game_file;
-  guint seed;
+  GRand *rand;
 } LoadIdleData;
 
 static void
@@ -2613,7 +2482,7 @@ load_error_response_cb (GtkWidget *dialog,
                         AisleriotWindow *window)
 {
   /* Load the default game */
-  aisleriot_window_set_game (window, DEFAULT_VARIATION, 0);
+  aisleriot_window_set_game (window, DEFAULT_VARIATION, NULL);
 
   gtk_widget_destroy (dialog);
 }
@@ -2623,6 +2492,7 @@ load_idle_cb (LoadIdleData *data)
 {
   AisleriotWindowPrivate *priv = data->window->priv;
   GError *error = NULL;
+  GRand *rand;
 
   if (!aisleriot_game_load_game (priv->game, data->game_file, &error)) {
     GtkWidget *dialog;
@@ -2673,7 +2543,10 @@ load_idle_cb (LoadIdleData *data)
     ar_conf_set_string (NULL, aisleriot_conf_get_key (CONF_VARIATION), data->game_file);
   }
 
-  aisleriot_game_new_game (priv->game, data->seed != 0 ? &data->seed : NULL);
+  rand = data->rand;
+  data->rand = NULL;
+
+  aisleriot_game_new_game_with_rand (priv->game, rand /* adopted */);
 
   gtk_widget_grab_focus (GTK_WIDGET (priv->board));
 
@@ -2685,6 +2558,9 @@ free_load_idle_data (LoadIdleData *data)
 {
   data->window->priv->load_idle_id = 0;
 
+  if (data->rand)
+    g_rand_free (data->rand);
+
   g_free (data->game_file);
   g_slice_free (LoadIdleData, data);
 }
@@ -2693,7 +2569,7 @@ free_load_idle_data (LoadIdleData *data)
  * aisleriot_window_set_game:
  * @window:
  * @game_file: a UTF-8 string
- * @seed:
+ * @rand: (allow-none) (transfer full): a #GRand, or %NULL
  *
  * Loads the game variation defined in the @game_file file.
  * Note that even though @game_file is used as a filename,
@@ -2702,7 +2578,7 @@ free_load_idle_data (LoadIdleData *data)
 void
 aisleriot_window_set_game (AisleriotWindow *window,
                            const char *game_file,
-                           guint seed)
+                           GRand *rand)
 {
   AisleriotWindowPrivate *priv = window->priv;
   LoadIdleData *data;
@@ -2715,7 +2591,7 @@ aisleriot_window_set_game (AisleriotWindow *window,
   data = g_slice_new (LoadIdleData);
   data->window = window;
   data->game_file = g_strdup (game_file);
-  data->seed = seed;
+  data->rand = rand; /* adopted */
 
   priv->load_idle_id = g_idle_add_full (G_PRIORITY_LOW,
                                         (GSourceFunc) load_idle_cb,
